@@ -35,7 +35,7 @@ func runPullsClean(_ stdctx.Context, cmd *cli.Command) error {
 	ctx := context.InitCommand(cmd)
 	ctx.Ensure(context.CtxRequirement{LocalRepo: true})
 	if ctx.Args().Len() != 1 {
-		return fmt.Errorf("Must specify a PR index")
+		return fmt.Errorf("pull request index is required")
 	}
 
 	idx, err := utils.ArgToIndex(ctx.Args().First())
